@@ -20,6 +20,7 @@
 #include <KIconUtils>
 #include <Sonnet/Speller>
 
+#include <QActionGroup>
 #include <QHBoxLayout>
 #include <QInputDialog>
 
@@ -28,9 +29,6 @@ KateStatusBarOpenUpMenu::KateStatusBarOpenUpMenu(QWidget *parent)
     : QMenu(parent)
 {
 }
-KateStatusBarOpenUpMenu::~KateStatusBarOpenUpMenu()
-{
-}
 
 void KateStatusBarOpenUpMenu::setVisible(bool visibility)
 {
@@ -38,8 +36,9 @@ void KateStatusBarOpenUpMenu::setVisible(bool visibility)
         QRect geo = geometry();
         QPoint pos = parentWidget()->mapToGlobal(QPoint(0, 0));
         geo.moveTopLeft(QPoint(pos.x(), pos.y() - geo.height()));
-        if (geo.top() < 0)
+        if (geo.top() < 0) {
             geo.moveTop(0);
+        }
         setGeometry(geo);
     }
 
@@ -56,9 +55,6 @@ StatusBarButton::StatusBarButton(KateStatusBar *parent, const QString &text /*=
     setMinimumSize(QSize(1, minimumSizeHint().height()));
 }
 
-StatusBarButton::~StatusBarButton()
-{
-}
 // END StatusBarButton
 
 KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
@@ -227,10 +223,10 @@ void KateStatusBar::contextMenuEvent(QContextMenuEvent *event)
         }
     }
 
-    QAction *showLines = menu.addAction(QStringLiteral("Show line count"), this, &KateStatusBar::toggleShowLines);
+    QAction *showLines = menu.addAction(i18n("Show line count"), this, &KateStatusBar::toggleShowLines);
     showLines->setCheckable(true);
     showLines->setChecked(KateViewConfig::global()->showLineCount());
-    QAction *showWords = menu.addAction(QStringLiteral("Show word count"), this, &KateStatusBar::toggleShowWords);
+    QAction *showWords = menu.addAction(i18n("Show word count"), this, &KateStatusBar::toggleShowWords);
     showWords->setCheckable(true);
     showWords->setChecked(KateViewConfig::global()->showWordCount());
     menu.exec(event->globalPos());
@@ -273,8 +269,9 @@ void KateStatusBar::viewModeChanged()
 {
     // prepend BLOCK for block selection mode
     QString text = m_view->viewModeHuman();
-    if (m_view->blockSelection())
+    if (m_view->blockSelection()) {
         text = i18n("[BLOCK] %1", text);
+    }
 
     m_inputMode->setText(text);
 }
@@ -354,8 +351,9 @@ void KateStatusBar::modifiedChanged()
 
     // combine to modified status, update only if changed
     unsigned int newStatus = (unsigned int)mod | ((unsigned int)modOnHD << 1) | ((unsigned int)readOnly << 2);
-    if (m_modifiedStatus == newStatus)
+    if (m_modifiedStatus == newStatus) {
         return;
+    }
 
     m_modifiedStatus = newStatus;
     switch (m_modifiedStatus) {
@@ -373,7 +371,7 @@ void KateStatusBar::modifiedChanged()
     case 0x2:
     case 0x6:
         m_modified->setIcon(QIcon::fromTheme(QStringLiteral("dialog-warning")));
-        m_modified->setWhatsThis(i18n("Meaning of current icon: Document was modified or deleted by another program"));
+        m_modified->setWhatsThis(i18n("Meaning of current icon: Document was modified or deleted on disk"));
         break;
 
     case 0x3:
@@ -454,8 +452,9 @@ void KateStatusBar::updateGroup(QActionGroup *group, int w)
     // linear search should be fast enough here, no additional hash
     for (QAction *action : group->actions()) {
         int val = action->data().toInt();
-        if (val == -1)
+        if (val == -1) {
             m1 = action;
+        }
         if (val == w) {
             found = true;
             action->setChecked(true);
@@ -479,8 +478,9 @@ void KateStatusBar::slotTabGroup(QAction *a)
     KateDocumentConfig *config = ((KTextEditor::DocumentPrivate *)m_view->document())->config();
     if (val == -1) {
         val = QInputDialog::getInt(this, i18n("Tab Width"), i18n("Please specify the wanted tab width:"), config->tabWidth(), 1, 200, 1, &ok);
-        if (!ok)
+        if (!ok) {
             val = config->tabWidth();
+        }
     }
     config->setTabWidth(val);
 }
@@ -499,13 +499,15 @@ void KateStatusBar::slotIndentGroup(QAction *a)
                                    200,
                                    1,
                                    &ok);
-        if (!ok)
+        if (!ok) {
             val = config->indentationWidth();
+        }
     }
     config->configStart();
     config->setIndentationWidth(val);
-    if (m_hardAction->isChecked())
+    if (m_hardAction->isChecked()) {
         config->setTabWidth(val);
+    }
     config->configEnd();
 }
 
@@ -515,8 +517,9 @@ void KateStatusBar::slotIndentTabMode(QAction *a)
     if (a == m_softAction) {
         config->setReplaceTabsDyn(true);
     } else if (a == m_mixedAction) {
-        if (config->replaceTabsDyn())
+        if (config->replaceTabsDyn()) {
             config->setReplaceTabsDyn(false);
+        }
         m_tabGroup->setEnabled(true);
     } else if (a == m_hardAction) {
         if (config->replaceTabsDyn()) {
