@@ -26,6 +26,7 @@
 #include <QScopedPointer>
 #include <QSpacerItem>
 #include <QTextLayout>
+#include <QTimer>
 
 #include <array>
 
@@ -117,6 +118,12 @@ public:
 
     void setInputMode(InputMode mode);
 
+public:
+    KateViewInternal *getViewInternal()
+    {
+        return m_viewInternal;
+    }
+
     //
     // KTextEditor::ClipboardInterface
     //
@@ -174,7 +181,7 @@ public:
 
     QPoint cursorPositionCoordinates() const override;
 
-    bool setCursorPositionVisual(const KTextEditor::Cursor &position);
+    bool setCursorPositionVisual(const KTextEditor::Cursor position);
 
     /**
      * Return the virtual cursor column, each tab is expanded into the
@@ -187,11 +194,11 @@ public:
     bool setMouseTrackingEnabled(bool enable) override;
 
 private:
-    void notifyMousePositionChanged(const KTextEditor::Cursor &newPosition);
+    void notifyMousePositionChanged(const KTextEditor::Cursor newPosition);
 
     // Internal
 public:
-    bool setCursorPositionInternal(const KTextEditor::Cursor &position, uint tabwidth = 1, bool calledExternally = false);
+    bool setCursorPositionInternal(const KTextEditor::Cursor position, uint tabwidth = 1, bool calledExternally = false);
 
     //
     // KTextEditor::ConfigInterface
@@ -258,7 +265,7 @@ public Q_SLOTS:
 public:
     KateCompletionWidget *completionWidget() const;
     mutable KateCompletionWidget *m_completionWidget;
-    void sendCompletionExecuted(const KTextEditor::Cursor &position, KTextEditor::CodeCompletionModel *model, const QModelIndex &index);
+    void sendCompletionExecuted(const KTextEditor::Cursor position, KTextEditor::CodeCompletionModel *model, const QModelIndex &index);
     void sendCompletionAborted();
 
     //
@@ -287,7 +294,7 @@ public:
     QVarLengthArray<KateInlineNoteData, 8> inlineNotes(int line) const;
 
 private:
-    QVector<KTextEditor::InlineNoteProvider *> m_inlineNoteProviders;
+    std::vector<KTextEditor::InlineNoteProvider *> m_inlineNoteProviders;
 
 private Q_SLOTS:
     void inlineNotesReset();
@@ -343,32 +350,32 @@ public:
     bool wrapCursor() const;
 
     // some internal functions to get selection state of a line/col
-    bool cursorSelected(const KTextEditor::Cursor &cursor);
+    bool cursorSelected(const KTextEditor::Cursor cursor);
     bool lineSelected(int line);
-    bool lineEndSelected(const KTextEditor::Cursor &lineEndPos);
+    bool lineEndSelected(const KTextEditor::Cursor lineEndPos);
     bool lineHasSelected(int line);
     bool lineIsSelection(int line);
 
     void ensureCursorColumnValid();
 
-    void tagSelection(const KTextEditor::Range &oldSelection);
+    void tagSelection(KTextEditor::Range oldSelection);
 
-    void selectWord(const KTextEditor::Cursor &cursor);
-    void selectLine(const KTextEditor::Cursor &cursor);
+    void selectWord(const KTextEditor::Cursor cursor);
+    void selectLine(const KTextEditor::Cursor cursor);
 
     // BEGIN EDIT STUFF
 public:
     void editStart();
     void editEnd(int editTagLineStart, int editTagLineEnd, bool tagFrom);
 
-    void editSetCursor(const KTextEditor::Cursor &cursor);
+    void editSetCursor(const KTextEditor::Cursor cursor);
     // END
 
     // BEGIN TAG & CLEAR
 public:
-    bool tagLine(const KTextEditor::Cursor &virtualCursor);
+    bool tagLine(const KTextEditor::Cursor virtualCursor);
 
-    bool tagRange(const KTextEditor::Range &range, bool realLines = false);
+    bool tagRange(KTextEditor::Range range, bool realLines = false);
     bool tagLines(KTextEditor::LineRange lineRange, bool realLines = false);
     bool tagLines(KTextEditor::Cursor start, KTextEditor::Cursor end, bool realCursors = false);
     bool tagLines(KTextEditor::Range range, bool realRange = false);
@@ -447,7 +454,7 @@ public:
     QString currentTextLine();
 
     QTextLayout *textLayout(int line) const;
-    QTextLayout *textLayout(const KTextEditor::Cursor &pos) const;
+    QTextLayout *textLayout(const KTextEditor::Cursor pos) const;
 
 public Q_SLOTS:
     void indent();
@@ -548,6 +555,14 @@ public Q_SLOTS:
      * @see KTextEditor::DocumentPrivate::transpose
      */
     void transpose();
+
+    /**
+     * Transpose the word at the current cursor position with the word to the right (or to the left for RTL layouts).
+     * If the word is the last in the line, try swapping with the previous word instead.
+     * If the word is the only one in the line, no swapping is done.
+     * @see KTextEditor::DocumentPrivate::swapTextRanges
+     */
+    void transposeWord();
     void cursorLeft();
     void shiftCursorLeft();
     void cursorRight();
@@ -706,7 +721,7 @@ public:
     }
 
 public:
-    void slotTextInserted(KTextEditor::View *view, const KTextEditor::Cursor &position, const QString &text);
+    void slotTextInserted(KTextEditor::View *view, const KTextEditor::Cursor position, const QString &text);
 
     void exportHtmlToFile(const QString &file);
 
@@ -733,7 +748,7 @@ private:
     void setupEditActions();
     void setupCodeFolding();
 
-    QList<QAction *> m_editActions;
+    std::vector<QAction *> m_editActions;
     QAction *m_editUndo;
     QAction *m_editRedo;
     QAction *m_pasteMenu;
@@ -820,7 +835,7 @@ private:
 
     // templates
 public:
-    bool insertTemplateInternal(const KTextEditor::Cursor &insertPosition, const QString &templateString, const QString &script = QString());
+    bool insertTemplateInternal(const KTextEditor::Cursor insertPosition, const QString &templateString, const QString &script = QString());
 
     /**
      * Accessors to the bars...
@@ -898,15 +913,15 @@ private:
 
     QString m_currentTextForHighlights;
 
-    QList<KTextEditor::MovingRange *> m_rangesForHighlights;
+    std::vector<std::unique_ptr<KTextEditor::MovingRange>> m_rangesForHighlights;
 
 public:
     /**
      * Attribute of a range changed or range with attribute changed in given line range.
      * @param lineRange line range that the change spans
-     * @param rangeWithAttribute attribute changed or is active, this will perhaps lead to repaints
+     * @param needsRepaint do we need to trigger repaints? e.g. if ranges with attributes change
      */
-    void notifyAboutRangeChange(KTextEditor::LineRange lineRange, bool rangeWithAttribute);
+    void notifyAboutRangeChange(KTextEditor::LineRange lineRange, bool needsRepaint);
 
 private Q_SLOTS:
     /**
@@ -956,9 +971,9 @@ public:
     //
 private:
     /**
-     * update already inited?
+     * delayed update timer
      */
-    bool m_delayedUpdateTriggered;
+    QTimer m_delayedUpdateTimer;
 
     /**
      * line range to update
@@ -1083,7 +1098,7 @@ private:
     bool m_autoFoldedFirstLine;
 
 public:
-    void setScrollPositionInternal(KTextEditor::Cursor &cursor);
+    void setScrollPositionInternal(KTextEditor::Cursor cursor);
 
     void setHorizontalScrollPositionInternal(int x);
 
